@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2015-03-10'; # DATE
-our $VERSION = '1.47'; # VERSION
+our $DATE = '2015-03-22'; # DATE
+our $VERSION = '1.48'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -744,15 +744,131 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.47 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-03-10.
+This document describes version 1.48 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-03-22.
 
 =head1 SYNOPSIS
 
-See L<Perinci::CmdLine::Manual::Examples>.
+In C<gen-random-num> script:
+
+ use Perinci::CmdLine::Classic;
+
+ our %SPEC;
+
+ $SPEC{gen_random_num} = {
+     v => 1.1,
+     summary => 'Generate some random numbers',
+     args => {
+         count => {
+             summary => 'How many numbers to generate',
+             schema => ['int*' => min=>0],
+             default => 1,
+             cmdline_aliases=>{n=>{}},
+             req => 1,
+             pos => 0,
+         },
+         min => {
+             summary => 'Lower limit of random number',
+             schema => 'float*',
+             default => 0,
+         },
+         max => {
+             summary => 'Upper limit of random number',
+             schema => 'float*',
+             default => 1,
+         },
+     },
+     result_naked => 1,
+ };
+ sub gen_random_num {
+     my %args = @_;
+
+     my @res;
+     for (1..$args{count}) {
+         push @res, $args{min} + rand()*($args{max}-$args{min});
+     }
+     \@res;
+ }
+
+ Perinci::CmdLine::Classic->new(url => '/main/gen_random_num')->run;
+
+Run your script:
+
+ % ./gen-random-num
+ 0.999473691060306
+
+ % ./gen-random-num --min 1 --max 10 5
+ 1.27390166158969
+ 1.69077475473679
+ 8.97748327778684
+ 5.86943773494068
+ 8.34341298182493
+
+JSON output support out of the box:
+
+ % ./gen-random-num -n3 --json
+ [200,"OK (envelope added by Perinci::Access::Lite)",[0.257073684902029,0.393782991540746,0.848740540017513],{}]
+
+Automatic help message:
+
+ % ./gen-random-num -h
+ gen-random-num - Generate some random numbers
+
+ Usage:
+   gen-random-num --help (or -h, -?)
+   gen-random-num --version (or -v)
+   gen-random-num [options] [count]
+ Options:
+   --config-path=s     Set path to configuration file
+   --config-profile=s  Set configuration profile to use
+   --count=i, -n       How many numbers to generate (=arg[0]) [1]
+   --format=s          Choose output format, e.g. json, text [undef]
+   --help, -h, -?      Display this help message
+   --json              Set output format to json
+   --max=f             Upper limit of random number [1]
+   --min=f             Lower limit of random number [0]
+   --naked-res         When outputing as JSON, strip result envelope [0]
+   --no-config         Do not use any configuration file
+   --version, -v
+
+Automatic configuration file support:
+
+ % cat ~/gen-random-num.conf
+ count=5
+ max=0.01
+
+ % ./gen-random-num
+ 0.00105268954838724
+ 0.00701443611501844
+ 0.0021247476506154
+ 0.00813872824513005
+ 0.00752832346491306
+
+Automatic tab completion support:
+
+ % complete -C gen-random-num gen-random-num
+ % gen-random-num --mi<tab>
+
+See the manual for details on other available features (subcommands, automatic
+formatting of data structures, automatic schema validation, dry-run mode,
+automatic POD generation, remote function support, automatic CLI generation,
+automatic --version, automatic HTTP API, undo/transactions, configurable output
+format, logging, progress bar, colors/Unicode, and more).
 
 =head1 DESCRIPTION
 
-See L<Perinci::CmdLine::Manual>.
+Perinci::CmdLine is a command-line application framework. It allows you to
+create full-featured CLI applications easily and quickly.
+
+See L<Perinci::CmdLine::Manual> for more details.
+
+There is also a blog post series on Perinci::CmdLine tutorial:
+L<https://perlancar.wordpress.com/category/pericmd-tut/>
+
+Perinci::CmdLine::Classic is the heavier backend implementation which supports
+some extra features currently not supported by the default backend
+implementation L<Perinci::CmdLine::Lite>. These features come at some startup
+overhead cost and more dependencies. You normally should use
+L<Perinci::CmdLine::Any> instead to be able to switch backend on the fly.
 
 Screenshots:
 
@@ -869,14 +985,7 @@ Please see L<Term::App::Role::Attrs>.
 
 =head1 SEE ALSO
 
-L<Perinci>, L<Rinci>, L<Riap>.
-
-L<Perinci::CmdLine::Base>.
-
-L<Perinci::CmdLine::Lite>.
-
-Other CPAN modules to write command-line applications: L<App::Cmd>, L<App::Rad>,
-L<MooseX::Getopt>.
+L<Perinci::CmdLine::Any>, L<Perinci::CmdLine::Lite>.
 
 =head1 HOMEPAGE
 
